@@ -3,6 +3,7 @@
 import pytest
 
 from statemachine import StateMachine, State
+from .conftest import campaign_machine, campaign_machine_with_values
 
 
 class MyModel(object):
@@ -14,38 +15,6 @@ class MyModel(object):
         return "{}({!r})".format(type(self).__name__, self.__dict__)
 
 
-@pytest.fixture
-def campaign_machine():
-    "Define a new class for each test"
-
-    class CampaignMachine(StateMachine):
-        draft = State('Draft', initial=True)
-        producing = State('Being produced')
-        closed = State('Closed')
-
-        add_job = draft.to(draft) | producing.to(producing)
-        produce = draft.to(producing)
-        deliver = producing.to(closed)
-
-    return CampaignMachine
-
-
-@pytest.fixture
-def campaign_machine_with_values():
-    "Define a new class for each test"
-
-    class CampaignMachineWithKeys(StateMachine):
-        draft = State('Draft', initial=True, value=1)
-        producing = State('Being produced', value=2)
-        closed = State('Closed', value=3)
-
-        add_job = draft.to(draft) | producing.to(producing)
-        produce = draft.to(producing)
-        deliver = producing.to(closed)
-
-    return CampaignMachineWithKeys
-
-
 def test_machine_should_be_at_start_state(campaign_machine):
     model = MyModel()
     machine = campaign_machine(model)
@@ -134,17 +103,20 @@ def test_should_change_state_with_multiple_machine_instances(campaign_machine):
     assert machine2.current_state == campaign_machine.producing
 
 
+@pytest.mark.parametrize('current_state, transition', [
+    ('draft', 'deliver'),
+    ('closed', 'add_job'),
+])
 def test_call_to_transition_that_is_not_in_the_current_state_should_raise_exception(
-        campaign_machine):
+        campaign_machine, current_state, transition):
 
-    model = MyModel()
+    model = MyModel(state=current_state)
     machine = campaign_machine(model)
 
-    assert model.state == 'draft'
-    assert machine.current_state == machine.draft
+    assert machine.current_state.value == current_state
 
     with pytest.raises(LookupError):
-        machine.deliver()
+        machine.run(transition)
 
 
 def test_machine_should_list_allowed_transitions_in_the_current_state(campaign_machine):
@@ -305,3 +277,19 @@ def test_state_machine_with_a_start_value(model, machine_cls, start_value):
 def test_state_machine_with_a_invalid_start_value(model, machine_cls, start_value):
     with pytest.raises(ValueError):
         machine_cls(model, start_value=start_value)
+
+
+def test_should_not_create_instance_of_machine_without_states():
+    class EmptyMachine(StateMachine):
+        pass
+
+    with pytest.raises(ValueError):
+        EmptyMachine()
+
+
+def test_should_not_create_instance_of_machine_without_transitions():
+    class NoTransitionsMachine(StateMachine):
+        initial = State('initial')
+
+    with pytest.raises(ValueError):
+        NoTransitionsMachine()
